@@ -51,7 +51,7 @@ class BaseApiClient:
         try:
             response.raise_for_status()
         except httpx.HTTPStatusError as exc:
-            raise raise_the_desired_api_error(exc)
+            raise_the_desired_api_error(exc)
         except httpx.RequestError as exc:
             raise HttpRequestError(message=exc.__str__())
         except httpx.ConnectError as exc:
