@@ -25,7 +25,7 @@ class HttpApiBaseException(HttpBaseException):
         super().__init__(original_exception=original_exception, message=message)
 
     def __str__(self):
-        return str(self.status_code)
+        return f'{self.status_code}:{self.message}'
 
 
 class Api4xxException(HttpApiBaseException):
@@ -44,15 +44,24 @@ class Api401Exception(Api4xxException):
     pass
 
 
+class Api400Exception(Api4xxException):
+    pass
+
+
 class Api500Exception(Api5xxException):
     pass
 
 
-
-def raise_the_desired_api_error(exception):
+def raise_the_desired_api_error(exception: httpx.HTTPStatusError):
     if exception.response.status_code == 404:
         raise Api404Exception(exception, message="404 не найдено")
     elif exception.response.status_code == 401:
         raise Api401Exception(exception, message="срок действия токена истек")
+    elif exception.response.status_code == 400:
+        raise Api400Exception(exception, message=exception.response.json()['message'])
+    elif exception.response.status_code in range(400, 499):
+        raise Api4xxException(exception, message="4хх ошибка")
     elif exception.response.status_code == 500:
         raise Api500Exception(exception)
+    elif exception.response.status_code > 500:
+        raise Api5xxException(exception)
