@@ -2,12 +2,10 @@ from pims_api_client.schemas import AttributeFilter, AttributeListItem
 from pims_api_client.schemas import PagedListResponse
 from typing import Optional
 from .base_executor import BaseExecutor
-from ..schemas.attributes import default_attribute_filter
-
 
 class AttributeMethodsExecutor(BaseExecutor):
 
-    async def fetch_attributes(self, params: AttributeFilter = default_attribute_filter):
+    async def fetch_attributes(self, params: AttributeFilter = AttributeFilter()):
 
         response = await self.client.get('pim/api/v1/attribute', params=params.dict())
         return PagedListResponse[AttributeListItem].parse_obj(response)
