@@ -1,10 +1,8 @@
 from typing import Optional
 from pydantic import BaseModel
+from .base import PerPageRequest
 
-
-class AttributeFilter(BaseModel):
-    page: int
-    per_page: int
+class AttributeFilter(PerPageRequest):
     name: Optional[str] = None
     type: Optional[str] = None
     group: Optional[str] = None
@@ -29,7 +27,4 @@ class AttributeGroupItem(BaseModel):
     id: str
     name: str
     code: str
-    position: int
-
-
-default_attribute_filter = AttributeFilter(page=1, per_page=20)
\ No newline at end of file
+    position: int
\ No newline at end of file
